@@ -1,6 +1,6 @@
 # This file is part of nvitop, the interactive NVIDIA-GPU process viewer.
 #
-# Copyright 2021-2024 Xuehai Pan. All Rights Reserved.
+# Copyright 2021-2025 Xuehai Pan. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -420,7 +420,7 @@ def __LoadCudaLibrary() -> None:
                         _itertools.chain.from_iterable((f'{lib}.1', lib) for lib in lib_filenames),
                     )
                 elif system == 'Windows':
-                    bits = _platform.architecture()[0].replace('bit', '')  # e.g., '64' or '32'
+                    bits = 8 * _ctypes.sizeof(_ctypes.c_void_p)  # 64 or 32
                     lib_filenames = [f'nvcuda{bits}.dll', 'nvcuda.dll']
                 # Open library
                 for lib_filename in lib_filenames:
