@@ -1,6 +1,6 @@
 # This file is part of nvitop, the interactive NVIDIA-GPU process viewer.
 #
-# Copyright 2021-2024 Xuehai Pan. All Rights Reserved.
+# Copyright 2021-2025 Xuehai Pan. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -451,7 +451,7 @@ def __LoadCudaLibrary() -> None:  # pylint: disable=too-many-branches
             if __cudaLib is None:  # pylint: disable=too-many-nested-blocks
                 # Platform specific libcudart location
                 system = _platform.system()
-                bits = _platform.architecture()[0].replace('bit', '')
+                bits = 8 * _ctypes.sizeof(_ctypes.c_void_p)  # 64 or 32
                 if system == 'Darwin':
                     lib_filenames = ['libcudart.dylib']
                 elif system == 'Linux':
