@@ -1,6 +1,6 @@
 # This file is part of nvitop, the interactive NVIDIA-GPU process viewer.
 #
-# Copyright 2021-2024 Xuehai Pan. All Rights Reserved.
+# Copyright 2021-2025 Xuehai Pan. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -323,7 +323,7 @@ def nvmlInitWithFlags(flags: int) -> None:  # pylint: disable=function-redefined
             ('https://developer.nvidia.com/cuda-downloads', None, ('underline',)),
             ('https://docs.nvidia.com/deploy/nvml-api', None, ('underline',)),
         ):
-            message = message.replace(text, __colored(text, color=color, attrs=attrs))
+            message = message.replace(text, __colored(text, color=color, attrs=attrs))  # type: ignore[arg-type]
 
         LOGGER.critical(message)
         raise
@@ -340,7 +340,7 @@ def nvmlInitWithFlags(flags: int) -> None:  # pylint: disable=function-redefined
             ('pynvml', None, ('bold',)),
             ('nvitop', None, ('bold',)),
         ):
-            message = message.replace(text, __colored(text, color=color, attrs=attrs), 1)
+            message = message.replace(text, __colored(text, color=color, attrs=attrs), 1)  # type: ignore[arg-type]
 
         LOGGER.critical(message)
         raise
